@@ -129,6 +129,42 @@ available_clocksource'
                     expect_not_kw='Unknown symbol',
                     msg='Check there is no Unknown symbol in dmesg')
 
+    def test_check_dmidecode_dump_segfault(self):
+        '''
+        case_name:
+            test_check_dmidecode_dump_segfault
+
+        case_priority:
+            2
+
+        component:
+            dmidecode
+
+        bugzilla_id:
+            1885823
+
+        customer_case_id:
+            02939365
+
+        polarion_id:
+            n/a
+
+        maintainer:
+            xiliang@redhat.com
+
+        description:
+            check there is no segmentation fault while run 'dmidecode --dump'
+
+        key_steps:
+            # dmidecode --dump |grep -i Segmentation 
+
+        expected_result:
+            No segmentation fault found.
+        '''
+        utils_lib.is_cmd_exist(self, cmd='dmidecode')
+        cmd = "sudo dmidecode --dump"
+        utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='Segmentation')
+
     def test_check_dmidecode_outofspec(self):
         '''
         bz: 1858350
@@ -528,7 +564,7 @@ in cmdline as bug1859088")
                     msg="It should be like: {}.n but it is {}".format(name_map[key], output))
                     if 'el6' not in kernel_ver and 'el7' not in kernel_ver:
                         rhversion = re.findall('Red Hat Enterprise Linux release \d', output)[0]
-                        cmd = "sudo grep -R 'Red Hat Enterprise Linux' /boot/grub*|grep -v '{}'".format(rhversion)
+                        cmd = "sudo grep -R 'Red Hat Enterprise Linux' /boot/grub*|grep -v '{}'".format(rhversion.replace('release ',''))
                         utils_lib.run_cmd(self, cmd, expect_not_ret=0, msg='make sure no other release name found')
                 else:
                     centos_key = "{}_centos".format(key)
@@ -616,7 +652,6 @@ in cmdline as bug1859088")
 
         '''
         cmd = 'systemctl'
-        utils_lib.run_cmd(self, cmd, expect_ret=0)
         utils_lib.run_cmd(self, cmd, expect_ret=0, expect_not_kw='failed')
 
     def test_check_sysfs_cpu_list(self):
